import { defineStore } from 'pinia';
import { ref, reactive, nextTick } from 'vue';
import { v4 } from 'uuid';

// 定义消息类型
export interface ChatMessage {
  id: string;
  role: string;
  content: string;
  timestamp?: number;
  pending?: boolean;
  error?: boolean;
  createAt?: Date;
}

export interface SendMessageOptions {
  messageId?: string;
  model?: string;
  [key: string]: any;
}

// WebSocket事件类型
export enum WebSocketEvent {
  CONNECTED = 'connected',
  DISCONNECTED = 'disconnected',
  MESSAGE = 'message',
  ERROR = 'error',
  MODEL_LIST = 'model_list',
  CHAT_UPDATE = 'chat_update'
}

// 定义VSCode API接口
let vscode: any = undefined;

try {
  vscode = acquireVsCodeApi();
} catch (error) {
  // 在开发环境下，可能没有VSCode API
  console.warn('VSCode API不可用，可能是在浏览器开发环境中运行');
}

// 添加常量定义
const REQUEST_TIMEOUT = 5000; // 请求超时时间（毫秒）
const LOCAL_STORAGE_REQUEST_ID_KEY = 'vscode_ai_chat_request_id'; // 保存requestId的localStorage键名

// WebSocket服务- 浏览器环境下实现
export class WebSocketService {
  private socket: WebSocket | null = null;
  private backoffTime = 1000;
  // 使用静态变量确保在同一个会话中所有的WebSocketService实例共享同一个requestId序列
  private static _nextRequestId = 1;
  private requestHandlers: Map<number, (response: any) => void> = new Map();
  private reconnectAttempts = 0;
  private reconnectTimer: NodeJS.Timeout | null = null;
  private readonly MAX_RECONNECT_ATTEMPTS = 5;
  private readonly RECONNECT_DELAY = 2000;
  private isReconnecting = false;
  private _hasLoggedRequestId = false; // 用于跟踪是否已记录过requestId
  
  // 内存存储，用于在localStorage不可用时的备用
  private static memoryStorage: Record<string, string> = {};
  
  public isConnected = false;
  public isLoading = false;
  public isWaitingForReply = false;
  public lastError: Error | null = null;
  public currentModel = ''; // 当前选择的模型
  public messages: ChatMessage[] = []; // 聊天消息历史
  private eventListeners: Map<string, Array<(data?: any) => void>> = new Map();

  /**
   * 安全地获取存储值，优先使用localStorage，失败时使用内存存储
   * @param key 存储键
   * @returns 存储的值或null
   */
  private safeGetItem(key: string): string | null {
    try {
      // 首先尝试从localStorage获取
      if (typeof localStorage !== 'undefined') {
        return localStorage.getItem(key);
      }
    } catch (error) {
      this.logger(`无法从localStorage读取数据: ${error}`);
    }
    
    // 回退到内存存储
    return WebSocketService.memoryStorage[key] || null;
  }

  /**
   * 安全地设置存储值，优先使用localStorage，失败时使用内存存储
   * @param key 存储键
   * @param value 要存储的值
   */
  private safeSetItem(key: string, value: string): void {
    try {
      // 首先尝试存储到localStorage
      if (typeof localStorage !== 'undefined') {
        localStorage.setItem(key, value);
        return;
      }
    } catch (error) {
      this.logger(`无法写入数据到localStorage: ${error}`);
    }
    
    // 回退到内存存储
    WebSocketService.memoryStorage[key] = value;
  }

  constructor(private apiUrl: string, private apiKey: string, private logger: (message: string) => void = console.log) {
    // 仅在类的静态变量_nextRequestId还是初始值时才从存储中恢复
    if (WebSocketService._nextRequestId === 1) {
      // 从存储中恢复requestId，确保在同一VSCode会话中保持一致
      const savedRequestId = this.safeGetItem(LOCAL_STORAGE_REQUEST_ID_KEY);
      
      if (savedRequestId) {
        const parsedId = parseInt(savedRequestId, 10);
        if (!isNaN(parsedId) && parsedId > 0) {
          WebSocketService._nextRequestId = parsedId;
          this.logger(`从存储中恢复requestId: ${WebSocketService._nextRequestId}`);
        } else {
          // 如果存储的值无效，生成一个新的随机ID并保存
          // 使用时间戳作为基础，确保唯一性
          const timestamp = Date.now();
          WebSocketService._nextRequestId = timestamp % 100000000 + Math.floor(Math.random() * 10000);
          this.safeSetItem(LOCAL_STORAGE_REQUEST_ID_KEY, WebSocketService._nextRequestId.toString());
          this.logger(`创建新的随机requestId: ${WebSocketService._nextRequestId} (基于时间戳)`);
        }
      } else {
        // 首次运行，创建新的随机ID
        // 使用时间戳作为基础，确保唯一性
        const timestamp = Date.now();
        WebSocketService._nextRequestId = timestamp % 100000000 + Math.floor(Math.random() * 10000);
        this.safeSetItem(LOCAL_STORAGE_REQUEST_ID_KEY, WebSocketService._nextRequestId.toString());
        this.logger(`创建新的随机requestId: ${WebSocketService._nextRequestId} (基于时间戳)`);
      }
    } else {
      // 静态变量已初始化，记录当前值
      this.logger(`使用已初始化的会话requestId: ${WebSocketService._nextRequestId}`);
    }
  }

  /**
   * 连接到WebSocket服务
   */
  public connect(): void {
    if (this.socket?.readyState === WebSocket.OPEN) {
      this.logger('[WebSocketService] 已连接');
      return;
    }

    try {
      this.logger(`[WebSocketService] 尝试连接 ${this.apiUrl}`);
      
      // 检查URL格式
      let wsUrl = this.apiUrl;
      
      // 确保URL以ws结尾，但避免重复
      if (!wsUrl.endsWith('/ws')) {
        if (wsUrl.endsWith('/')) {
          wsUrl += 'ws';
        } else {
          wsUrl += '/ws';
        }
      }
      
      // 检查是否有API密钥，如果有则添加为查询参数
      if (this.apiKey) {
        const separator = wsUrl.includes('?') ? '&' : '?';
        wsUrl += `${separator}api_key=${this.apiKey}`;
      }
      
      this.logger(`[WebSocketService] 最终WebSocket URL: ${wsUrl}`);
      
      // 标记是否需要尝试使用127.0.0.1代替localhost
      let shouldTryWithIP = false;
      
      // 检查是否使用了localhost
      if (wsUrl.includes('localhost')) {
        shouldTryWithIP = true;
      }
      
      // 首先尝试原始URL连接
      this.socket = new WebSocket(wsUrl);
      
      // 设置连接超时，如果3秒内未连接成功，尝试备用方式
      const connectionTimeout = window.setTimeout(() => {
        // 检查连接状态
        if (this.socket && this.socket.readyState !== WebSocket.OPEN) {
          this.logger('[WebSocketService] 连接超时，尝试备用连接方式');
          
          // 关闭当前连接
          try {
            this.socket.close();
          } catch (err) {
            // 忽略关闭错误
          }
          
          // 如果使用了localhost，尝试使用127.0.0.1替换
          if (shouldTryWithIP) {
            const ipUrl = wsUrl.replace('localhost', '127.0.0.1');
            this.logger(`[WebSocketService] 尝试使用IP地址替代localhost: ${ipUrl}`);
            
            // 创建新的WebSocket连接
            this.socket = new WebSocket(ipUrl);
            this.setupEventHandlers();
          }
        }
      }, 3000);
      
      // 保存连接超时处理器，以便在setupEventHandlers中清除
      (this.socket as any)._connectionTimeout = connectionTimeout;
      
      // 设置事件处理器
      this.setupEventHandlers();
    } catch (error) {
      this.logger(`[WebSocketService] 连接失败: ${error}`);
      this.emit(WebSocketEvent.ERROR, `连接失败: ${error}`);
      this.scheduleReconnect();
    }
  }

  /**
   * 断开WebSocket连接
   */
  public disconnect(): void {
    this.clearTimers();
    
    if (this.socket) {
      try {
        this.socket.close();
      } catch (err) {
        this.logger(`关闭WebSocket时出错: ${err}`);
      }
      this.socket = null;
    }
    
    this.isConnected = false;
    this.emit(WebSocketEvent.DISCONNECTED);
  }

  /**
   * 监听事件
   */
  public on(event: WebSocketEvent, callback: (data?: any) => void): void {
    if (!this.eventListeners.has(event)) {
      this.eventListeners.set(event, []);
    }
    
    this.eventListeners.get(event)?.push(callback);
  }

  /**
   * 移除事件监听
   */
  public off(event: WebSocketEvent, callback: (data?: any) => void): void {
    const listeners = this.eventListeners.get(event);
    if (listeners) {
      const index = listeners.indexOf(callback);
      if (index !== -1) {
        listeners.splice(index, 1);
      }
    }
  }

  /**
   * 触发事件
   */
  private emit(event: WebSocketEvent, data?: any): void {
    const listeners = this.eventListeners.get(event);
    if (listeners) {
      listeners.forEach(callback => callback(data));
    }
  }

  /**
   * 设置WebSocket事件处理器
   */
  private setupEventHandlers(): void {
    if (!this.socket) {
      this.logger('[WebSocketService] 无法设置事件处理器 socket为null');
      return;
    }
    
    // 清除连接超时
    if ((this.socket as any)._connectionTimeout) {
      window.clearTimeout((this.socket as any)._connectionTimeout);
      delete (this.socket as any)._connectionTimeout;
    }
    
    // 记录连接建立时间
    let connectionEstablishedTime = 0;
    
    // 使用浏览器风格的事件处理
    this.socket.onopen = () => {
      this.logger('[WebSocketService] WebSocket连接已建立成功');
      this.isConnected = true;
      connectionEstablishedTime = Date.now();
      
      // 延迟重置重连计数器，确保连接稳定
      setTimeout(() => {
        if (this.isConnected) {
          this.logger('[WebSocketService] 连接保持稳定，重置重连计数器');
        }
      }, 5000);
      
      this.emit(WebSocketEvent.CONNECTED);
      this.logger('[WebSocketService] 已触发CONNECTED事件');
      
      // 连接后立即获取模型列表
      this.logger('[WebSocketService] 开始获取初始模型列表');
      this.getModelList()
        .then(models => {
          this.logger(`[WebSocketService] 获取初始模型列表成功: ${JSON.stringify(models)}`);
          this.emit(WebSocketEvent.MODEL_LIST, models);
        })
        .catch(error => {
          this.logger(`[WebSocketService] 获取初始模型列表失败: ${error}`);
        });
    };
    
    this.socket.onmessage = (event: MessageEvent) => {
      try {
        const data = event.data;
        
        // 检查是否是HTTP错误响应
        const stringData = typeof data === 'string' ? data : data.toString();
        
        // 完整记录服务器响应，确保能看到全部内容
        this.logger(`WebSocket完整响应原始数据(长度: ${stringData.length}):\n${stringData}`);
        
        // 尝试解析JSON
        let response;
        try {
          response = JSON.parse(stringData);
          this.logger(`成功解析WebSocket响应为JSON: ${JSON.stringify(response, null, 2)}`);
        } catch (jsonError) {
          this.logger(`无法解析JSON响应: ${jsonError}, 原始消息: ${stringData}`);
          
          // 尝试处理非JSON响应（如纯文本响应）
          if (typeof stringData === 'string' && stringData.trim().length > 0) {
            this.logger(`使用纯文本方式处理响应: ${stringData}`);
            
            // 查找最新的请求ID
            if (this.requestHandlers.size > 0) {
              // 使用最大的数字作为最新请求ID
              const keys = Array.from(this.requestHandlers.keys());
              let latestRequestId = keys[0];
              for (const key of keys) {
                if (key > latestRequestId) {
                  latestRequestId = key;
                }
              }
              
              const callback = this.requestHandlers.get(latestRequestId);
              if (callback) {
                this.logger(`将纯文本响应传递给请求ID ${latestRequestId}`);
                callback(stringData); // 直接将文本传递给回调
                // 处理完成后删除处理器，避免重复
                this.requestHandlers.delete(latestRequestId);
              } else {
                this.logger(`找到最新请求ID ${latestRequestId}，但没有相应的回调处理器`);
              }
            } else {
              this.logger(`没有活跃的请求，无法处理纯文本响应`);
              
              // 尝试创建通用消息
              const genericMessage: ChatMessage = {
                id: `generic-${Date.now()}`,
                content: stringData,
                role: 'assistant',
                timestamp: Date.now()
              };
              
              // 发送通用消息
              this.emit(WebSocketEvent.MESSAGE, genericMessage);
            }
            return;
          }
          
          this.emit(WebSocketEvent.ERROR, `服务器返回的不是有效JSON: ${stringData}`);
          // 自动发送默认模型列表，避免前端卡住
          this.emit(WebSocketEvent.MODEL_LIST, this.getDefaultModels());
          return;
        }
        
        // 处理错误响应
        if (response.error) {
          this.handleErrorResponse(response);
          return;
        }
        
        // 处理模型列表响应（特殊处理）
        if (response.models && Array.isArray(response.models)) {
          this.logger(`收到模型列表响应: ${JSON.stringify(response.models)}`);
          
          // 查找对应的模型列表请求
          let modelRequestId = 0;
          for (const [reqId, _] of this.requestHandlers.entries()) {
            // 尝试通过检查是否为较小的数字来猜测是模型列表请求
            if (reqId < 100) {
              modelRequestId = reqId;
              break;
            }
          }
          
          if (modelRequestId > 0) {
            const callback = this.requestHandlers.get(modelRequestId);
            if (callback) {
              this.logger(`调用模型列表请求处理器: ${modelRequestId}`);
              callback(response);
              this.requestHandlers.delete(modelRequestId);
            } else {
              this.logger(`找到模型列表请求ID ${modelRequestId}，但没有相应的回调处理器`);
            }
          } else {
            this.logger(`收到模型列表，但没有找到对应的模型列表请求`);
          }
          
          // 无论找到对应请求与否，都通知模型列表更新
          this.emit(WebSocketEvent.MODEL_LIST, response.models);
          return;
        }
        
        // 尝试查找响应中的任何文本内容
        const hasTextContent = this.hasAnyTextContent(response);
        if (hasTextContent) {
          this.logger(`响应中包含文本内容`);
        } else {
          this.logger(`响应中不包含文本内容: ${JSON.stringify(response)}`);
        }
        
        // 获取请求ID - 只使用标准格式 request_id
        const requestId = response.request_id;
        
        // 处理消息命令的响应
        if (requestId !== undefined) {
          // 将请求ID转换为数字
          const numRequestId = typeof requestId === 'string' ? parseInt(requestId, 10) : requestId;
          
          if (!isNaN(numRequestId) && this.requestHandlers.has(numRequestId)) {
            const callback = this.requestHandlers.get(numRequestId);
            if (callback) {
              // 向处理器传递响应
              this.logger(`调用请求${numRequestId}的回调处理器`);
              callback(response);
              
              // 检查是否是流式响应的最后一个包
              const isLastPacket = 
                response.stream_finsh === true || // 文档中的拼写错误
                response.stream_finish === true; // 可能的正确拼写
              
              if (isLastPacket) {
                this.logger(`收到最后一个数据包，移除请求处理器: ${numRequestId}`);
                this.requestHandlers.delete(numRequestId);
              }
            } else {
              this.logger(`找到请求ID ${numRequestId}，但没有相应的回调处理器`);
            }
            return;
          }
        }
        
        // 如果响应中有文本内容但没有请求ID，创建通用消息
        if (hasTextContent) {
          this.logger(`收到没有请求ID的响应，但包含文本内容，作为通用消息处理`);
          
          // 尝试从响应中提取任何有用的文本
          let content = this.extractResponseContent(response);
          
          // 创建一个通用消息
          const genericMessage: ChatMessage = {
            id: `generic-${Date.now()}`,
            content: content,
            role: 'assistant',
            timestamp: Date.now()
          };
          
          // 发送通用消息
          this.emit(WebSocketEvent.MESSAGE, genericMessage);
          return;
        }
        
        // 其他未识别的响应处理为通用消息
        this.logger(`收到未知类型的WebSocket消息，作为通用消息处理: ${JSON.stringify(response)}`);
        
        // 尝试从响应中提取任何有用的文本
        let content = this.extractResponseContent(response);
        
        // 创建一个通用消息
        const genericMessage: ChatMessage = {
          id: `generic-${Date.now()}`,
          content: content,
          role: 'assistant',
          timestamp: Date.now()
        };
        
        // 发送通用消息
        this.emit(WebSocketEvent.MESSAGE, genericMessage);
      } catch (error) {
        this.logger(`解析WebSocket消息失败: ${error}, 原始消息: ${typeof event.data === 'string' ? event.data : '非文本数据'}`);
        // 自动发送默认模型列表，避免前端卡住
        this.emit(WebSocketEvent.MODEL_LIST, this.getDefaultModels());
      }
    };
    
    this.socket.onerror = (event: Event) => {
      const errorDetails = JSON.stringify(event);
      this.logger(`[WebSocketService] WebSocket错误事件: ${errorDetails}`);
      
      // 检查是否包含isTrusted属性
      if (event && 'isTrusted' in event && event.isTrusted) {
        this.logger('[WebSocketService] 这是一个受信任的错误事件，可能是证书或安全设置导致');
        
        // 获取更多诊断信息
        let diagInfo = '';
        
        // 检查是否是localhost
        if (this.apiUrl.includes('localhost') || this.apiUrl.includes('127.0.0.1')) {
          diagInfo += '本地连接(localhost)可能需要特殊权限 ';
          
          // 建议使用127.0.0.1而不是localhost
          if (this.apiUrl.includes('localhost')) {
            diagInfo += '建议尝试使用127.0.0.1替代localhost; ';
          }
        }
        
        // 检查是否使用了wss安全连接
        if (this.apiUrl.startsWith('wss://')) {
          diagInfo += '使用了安全WebSocket连接，请确认服务器证书有效 ';
        } else {
          // 如果使用ws不安全连接，可能是混合内容问题
          diagInfo += 'VS Code中使用不安全WebSocket(ws://)可能受到限制，建议使用安全连接wss://); ';
        }
        
        // 检查WebView上下文
        if (typeof window !== 'undefined' && 'acquireVsCodeApi' in window) {
          diagInfo += 'WebView环境中可能有额外的安全限制 ';
        }
        
        const errorMessage = `连接错误(isTrusted): ${diagInfo}请检查服务器配置和网络连接`;
        this.emit(WebSocketEvent.ERROR, errorMessage);
      } else {
        this.emit(WebSocketEvent.ERROR, `连接错误: ${errorDetails}`);
      }
      
      // 重连
      if (this.socket?.readyState !== WebSocket.OPEN) {
        this.logger('[WebSocketService] Socket未处于OPEN状态，安排重连');
        this.scheduleReconnect();
      }
    };
    
    this.socket.onclose = (event: CloseEvent) => {
      this.logger(`[WebSocketService] WebSocket连接关闭: 代码=${event.code} (${this.getCloseEventReason(event.code)}), 原因=${event.reason || '未提供'}`);
      this.isConnected = false;
      
      // 计算连接持续时间
      if (connectionEstablishedTime > 0) {
        const duration = Date.now() - connectionEstablishedTime;
        this.logger(`[WebSocketService] 连接持续时间: ${duration}ms`);
      }
      
      this.clearTimers();
      this.emit(WebSocketEvent.DISCONNECTED);
      this.logger('[WebSocketService] 已触发DISCONNECTED事件');
      
      // 如果不是正常关闭，尝试重连
      if (event.code !== 1000) {
        this.logger('[WebSocketService] 非正常关闭，安排重连');
        this.scheduleReconnect();
      }
    };
    
    this.logger('[WebSocketService] 所有WebSocket事件处理器已设置完成');
  }

  /**
   * 生成唯一的请求ID - 在同一会话内保持不变，确保所有请求使用相同的ID
   */
  private generateRequestId(): number {
    // 不再自增，每次返回相同的请求ID
    // 仅在初始请求时记录日志，避免日志过多
    if (!this._hasLoggedRequestId) {
      this.logger(`使用固定请求ID: ${WebSocketService._nextRequestId} (会话中保持一致)`);
      this._hasLoggedRequestId = true;
    }
    
    return WebSocketService._nextRequestId;
  }

  /**
   * 将消息添加到消息列表
   * @param message 聊天消息
   */
  private addMessageToList(message: ChatMessage) {
    // 添加消息到列表
    this.messages.push(message);
    // 触发消息列表更新事件
    this.emit(WebSocketEvent.CHAT_UPDATE);
  }

  /**
   * 更新消息列表中的特定消息
   * @param message 要更新的消息
   */
  public updateMessage(message: ChatMessage) {
    const index = this.messages.findIndex(msg => msg.id === message.id);
    if (index !== -1) {
      // 更新消息
      this.messages[index] = message;
      // 触发消息列表更新事件
      this.emit(WebSocketEvent.CHAT_UPDATE);
    } else {
      this.logger(`尝试更新不存在的消息: ${message.id}`);
    }
  }

  /**
   * 添加请求处理器
   * @param requestId 请求ID
   * @param callback 回调函数
   */
  private addRequest(requestId: number, callback: (response: any) => void): void {
    this.requestHandlers.set(requestId, callback);
    
    // 设置超时处理
    setTimeout(() => {
      if (this.requestHandlers.has(requestId)) {
        this.logger(`请求 ${requestId} 超时，移除处理器`);
        this.requestHandlers.delete(requestId);
        callback({ error: '请求超时' });
      }
    }, REQUEST_TIMEOUT);
  }

  /**
   * 获取模型列表
   */
  public getModelList(): Promise<string[]> {
    return new Promise((resolve, reject) => {
      if (!this.isConnected || !this.socket) {
        this.logger('尝试获取模型列表，但WebSocket未连接');
        return reject(new Error('WebSocket未连接'));
      }

      const requestId = this.generateRequestId();
      
      // 创建符合API文档格式的请求
      const request = {
        cmd: 'list_model',
        request_id: requestId
      };

      this.logger(`请求模型列表: ${JSON.stringify(request)}`);
      
      // 添加请求处理器
      this.addRequest(requestId, (response) => {
        if (response.error) {
          this.logger(`获取模型列表失败: ${response.error}`);
          return reject(new Error(`获取模型列表失败: ${response.error}`));
        }
        
        // 确保模型列表存在且是数组
        if (response.models && Array.isArray(response.models)) {
          this.logger(`成功获取模型列表: ${response.models.join(', ')}`);
          resolve(response.models);
        } else {
          this.logger('获取模型列表失败：返回格式不正确');
          reject(new Error('获取模型列表失败：返回格式不正确'));
        }
      });

      // 发送请求
      this.socket.send(JSON.stringify(request));
    });
  }

  /**
   * 发送聊天消息
   * @param content 消息内容
   * @param modelId 模型ID
   * @param conversationId 会话ID
   * @param customAIMessageId 自定义AI消息ID (可选)
   * @returns 
   */
  public sendChatMessage(
    content: string,
    modelId?: string,
    conversationId?: string,
    customAIMessageId?: string
  ): Promise<ChatMessage> {
    return new Promise<ChatMessage>((resolve, reject) => {
      // 确保设置加载状态
      this.isLoading = true;
      this.isWaitingForReply = true;
      
      // 创建用户消息对象
      const userMsg: ChatMessage = {
        id: v4(),
        role: "user",
        content,
        createAt: new Date()
      };

      // 将用户消息添加到消息列表
      this.addMessageToList(userMsg);

      // 创建请求ID
      const requestId = this.generateRequestId();
      
      // 创建AI响应消息对象
      const aiMsg: ChatMessage = {
        id: customAIMessageId || v4(), // 使用自定义ID或生成新的UUID
        role: "assistant",
        content: "正在思考中...",
        pending: true,
        createAt: new Date()
      };

      // 将AI消息添加到消息列表
      this.addMessageToList(aiMsg);
      
      // 明确触发消息更新事件
      this.emit(WebSocketEvent.CHAT_UPDATE);

      // 设置超时处理，如果10秒内没有收到真正的响应，重置loading状态
      const timeoutId = setTimeout(() => {
        if (aiMsg.pending) {
          this.logger(`5分钟后未收到真正的AI响应，重置loading状态`);
          aiMsg.pending = false;
          aiMsg.content = "抱歉，未能及时获取到回复，请稍后再试。";
          this.isLoading = false;
          this.isWaitingForReply = false;
          this.updateMessage(aiMsg);
          this.emit(WebSocketEvent.CHAT_UPDATE);
        }
      }, 300000);

      // 注册响应处理器
      this.requestHandlers.set(requestId, (data: any) => {
        try {
          // 首先清除超时定时器
          clearTimeout(timeoutId);
          
          this.logger(`收到AI响应: ${JSON.stringify(data)}`);
          
          // 检查是否是取消响应
          if (data.canceled) {
            this.logger('请求已被用户取消');
            aiMsg.content = data.msg || "用户已取消生成";
            aiMsg.pending = false;
            this.updateMessage(aiMsg);
            this.isLoading = false;
            this.isWaitingForReply = false;
            this.emit(WebSocketEvent.CHAT_UPDATE);
            resolve(aiMsg);
            return;
          }
          
          // 根据响应更新AI消息
          const responseContent = data.msg || data.message || data.answer || data.content || "";
          
          // 无论内容如何，都更新AI消息
          aiMsg.content = responseContent;
          aiMsg.pending = false;
          
          // 如果响应中包含时间戳，则更新createAt
          if (data.timestamp) {
            aiMsg.createAt = new Date(data.timestamp);
          }
          
          // 更新消息列表
          this.updateMessage(aiMsg);
          
          // 通知聊天视图刷新
          this.emit(WebSocketEvent.CHAT_UPDATE);
          
          // 标记加载完成
          this.isLoading = false;
          this.isWaitingForReply = false;
          
          // 解决Promise
          resolve(aiMsg);
        } catch (error) {
          this.logger(`处理AI响应时出错: ${error}`);
          aiMsg.content = "处理响应时发生错误";
          aiMsg.error = true;
          aiMsg.pending = false;
          this.updateMessage(aiMsg);
          
          // 确保重置状态
          this.isLoading = false;
          this.isWaitingForReply = false;
          this.emit(WebSocketEvent.CHAT_UPDATE);
          
          reject(error);
        }
      });

      // 准备并发送请求
      const request = {
        cmd: "exec_chat",
        request_id: requestId,
        msg: content,
        model: modelId,
        stream: false
      };
      
      this.logger(`发送聊天请求: ${JSON.stringify(request)}`);
      
      // 尝试发送请求
      try {
        this.sendRequest(request);
      } catch (error) {
        // 处理发送请求时的错误
        clearTimeout(timeoutId);
        this.logger(`发送请求失败: ${error}`);
        aiMsg.content = `发送请求失败: ${error instanceof Error ? error.message : '未知错误'}`;
        aiMsg.error = true;
        aiMsg.pending = false;
        this.updateMessage(aiMsg);
        
        // 确保重置状态
        this.isLoading = false;
        this.isWaitingForReply = false;
        this.emit(WebSocketEvent.CHAT_UPDATE);
        
        // 从处理器映射中移除
        this.requestHandlers.delete(requestId);
        
        reject(error);
      }
    });
  }
  
  /**
   * 发送请求到WebSocket服务器
   * @param request 请求对象
   */
  public sendRequest(request: any): void {
    if (!this.socket || this.socket.readyState !== WebSocket.OPEN) {
      this.logger(`无法发送请求，WebSocket未连接: ${JSON.stringify(request)}`);
      throw new Error('WebSocket未连接');
    }
    
    try {
      // 确保请求有正确的格式
      if (!request.cmd) {
        // 如果没有cmd字段，尝试添加
        if (request.msg) {
          request.cmd = 'exec_chat';
        } else {
          request.cmd = 'unknown';
        }
      }
      
      // 发送JSON格式化的请求
      this.socket.send(JSON.stringify(request));
      this.logger(`已发送请求: ${JSON.stringify(request)}`);
    } catch (error) {
      this.logger(`发送请求失败: ${error}, 请求: ${JSON.stringify(request)}`);
      throw error;
    }
  }
  
  /**
   * 从响应中提取内容
   */
  private extractResponseContent(response: any): string {
    // 提取响应内容
    let content = '';
    
    if (typeof response === 'string') {
      content = response;
    } else if (response && response.msg) {
      content = response.msg;
    } else if (response && response.content) {
      content = response.content;
    } else if (response && this.hasAnyTextContent(response)) {
      // 检查常用文本字段
      const textFields = ['msg', 'message', 'content', 'text', 'response'];
      for (const field of textFields) {
        if (typeof response[field] === 'string' && response[field].trim().length > 0) {
          content = response[field];
          break;
        }
      }
    } else if (response) {
      content = JSON.stringify(response);
    } else {
      content = '收到空响应';
    }
    
    return content;
  }

  /**
   * 获取WebSocket ReadyState的描述
   */
  private getReadyStateDescription(state: number): string {
    switch (state) {
      case WebSocket.CONNECTING:
        return '正在连接 (CONNECTING: 0)';
      case WebSocket.OPEN:
        return '已连接(OPEN: 1)';
      case WebSocket.CLOSING:
        return '正在关闭 (CLOSING: 2)';
      case WebSocket.CLOSED:
        return '已关闭(CLOSED: 3)';
      default:
        return `未知状态: ${state}`;
    }
  }

  /**
   * 安排重连
   */
  private scheduleReconnect(): void {
    if (this.isReconnecting || this.reconnectAttempts >= this.MAX_RECONNECT_ATTEMPTS) {
      if (this.reconnectAttempts >= this.MAX_RECONNECT_ATTEMPTS) {
        this.logger(`达到最大重连尝试次数(${this.MAX_RECONNECT_ATTEMPTS})，停止重连`);
        this.emit(WebSocketEvent.ERROR, `连接失败：已尝试 ${this.MAX_RECONNECT_ATTEMPTS} 次重连，请检查网络或服务器状态后手动重连`);
      }
      return;
    }
    
    this.isReconnecting = true;
    this.reconnectAttempts++;
    
    // 使用指数退避策略和随机抖动
    const baseDelay = this.RECONNECT_DELAY * Math.pow(1.5, this.reconnectAttempts - 1);
    const jitter = Math.random() * 1000; // 添加最多1秒的随机抖动
    const delay = Math.min(baseDelay + jitter, 30000); // 上限30秒
    
    this.logger(`尝试重新连接 (${this.reconnectAttempts}/${this.MAX_RECONNECT_ATTEMPTS}), 延迟 ${delay}ms`);
    
    this.reconnectTimer = window.setTimeout(() => {
      this.isReconnecting = false;
      this.connect();
    }, delay) as unknown as NodeJS.Timeout;
  }

  /**
   * 清除所有定时器
   */
  private clearTimers(): void {
    if (this.reconnectTimer !== null) {
      window.clearTimeout(this.reconnectTimer);
      this.reconnectTimer = null;
    }
  }

  /**
   * 获取默认模型列表
   */
  private getDefaultModels(): string[] {
    return ['qwq:latest', 'deepseek-r1:32b', 'qwen2.5-coder:7b'];
  }

  /**
   * 获取WebSocket关闭代码解释
   */
  private getCloseEventReason(code: number): string {
    const explanations: Record<number, string> = {
      1000: '正常关闭',
      1001: '端点离开',
      1002: '协议错误',
      1003: '无法接受数据',
      1004: '保留',
      1005: '未提供状态码',
      1006: '异常关闭',
      1007: '数据类型不一致,',
      1008: '违反策略',
      1009: '消息太大',
      1010: '必需的扩展缺失,',
      1011: '内部错误',
      1012: '服务重启',
      1013: '临时错误',
      1014: '服务器超,',
      1015: 'TLS握手失败'
    };
    
    return explanations[code] || `未知代码: ${code}`;
  }

  /**
   * 检查响应是否包含任何文本内容
   */
  private hasAnyTextContent(response: any): boolean {
    if (!response || typeof response !== 'object') {
      return false;
    }
    
    // 检查常用文本字段
    const textFields = ['msg', 'message', 'content', 'text', 'response'];
    for (const field of textFields) {
      if (typeof response[field] === 'string' && response[field].trim().length > 0) {
        return true;
      }
    }
    
    // 检查任何字符串属性
    for (const key in response) {
      if (typeof response[key] === 'string' && response[key].trim().length > 0) {
        return true;
      }
    }
    
    return false;
  }

  // 处理错误响应
  private handleErrorResponse(response: any): void {
    // 创建格式化的错误消息
    const formattedError = `服务器错误: ${response.error}`;
    this.logger(formattedError);
    
    // 区分不同类型的错误，但保持连接状态
    // 在文档中，错误通过error字段返回，我们需要区分严重错误和格式错误
    if (response.error && (response.error === 'invalid request format' || response.error === 'unknown cmd')) {
      // 对于请求格式错误，只记录但不改变连接状态
      this.logger(`请求格式错误，但连接仍然有效: ${JSON.stringify(response)}`);
    } else {
      // 其他错误可能是服务器问题或连接问题，触发ERROR事件
      this.emit(WebSocketEvent.ERROR, formattedError);
    }
    
    // 对于模型相关错误，特别处理
    if (response.error && (response.error.includes('model') || response.error.includes('unknown model'))) {
      this.logger('检测到模型相关错误，通知前端');
      
      const errorMessage: ChatMessage = {
        id: `error-model-${Date.now()}`,
        content: `错误: 模型 "${response.model || '未知'}" 不可用或不存在，请尝试其他模型`,
        role: 'assistant',
        timestamp: Date.now()
      };
      
      this.emit(WebSocketEvent.MESSAGE, errorMessage);
    }
    
    // 对于请求相关的错误，将错误传递给请求处理器
    if (response.request_id !== undefined) {
      // 将请求ID转换为number类型
      const numRequestId = typeof response.request_id === 'string' 
        ? parseInt(response.request_id, 10) 
        : response.request_id;
      
      if (!isNaN(numRequestId) && this.requestHandlers.has(numRequestId)) {
        const callback = this.requestHandlers.get(numRequestId);
        if (callback) {
          this.logger(`将错误响应传递给请求处理器: ${numRequestId}`);
          callback(response);
          // 处理完成后移除处理器
          this.requestHandlers.delete(numRequestId);
        }
      } else {
        this.logger(`错误响应没有有效的请求ID或找不到对应的请求处理器`);
        
        // 创建一个通用错误消息
        const errorMessage: ChatMessage = {
          id: `error-${Date.now()}`,
          content: `错误: ${response.error}`,
          role: 'assistant',
          timestamp: Date.now()
        };
        
        // 发送错误消息
        this.emit(WebSocketEvent.MESSAGE, errorMessage);
      }
    } else {
      this.logger(`错误响应没有请求ID`);
      
      // 创建一个通用错误消息
      const errorMessage: ChatMessage = {
        id: `error-${Date.now()}`,
        content: `错误: ${response.error}`,
        role: 'assistant',
        timestamp: Date.now()
      };
      
      // 发送错误消息
      this.emit(WebSocketEvent.MESSAGE, errorMessage);
    }
  }

  /**
   * 取消当前正在处理的聊天请求
   * @returns 是否有请求被取消
   */
  public cancelCurrentRequest(): boolean {
    this.logger('正在尝试取消当前请求');
    
    // 找到最新的请求ID
    if (this.requestHandlers.size === 0) {
      this.logger('没有活跃的请求处理程序，无法取消');
      // 无论如何，确保重置状态
      this.isLoading = false;
      this.isWaitingForReply = false;
      
      // 清理任何挂起的消息状态
      const pendingMessage = this.messages.find(m => m.pending);
      if (pendingMessage) {
        pendingMessage.pending = false;
        pendingMessage.content = "已结束";
        this.updateMessage(pendingMessage);
        this.emit(WebSocketEvent.CHAT_UPDATE);
      }
      
      return false;
    }
    
    // 获取所有请求ID并找到最大的（最新的）
    const requestIds = Array.from(this.requestHandlers.keys());
    const latestRequestId = Math.max(...requestIds);
    
    this.logger(`找到最新的请求ID: ${latestRequestId}，正在取消`);
    
    // 移除对应的请求处理程序
    const handler = this.requestHandlers.get(latestRequestId);
    if (handler) {
      // 调用处理程序，传递取消状态
      handler({ canceled: true, msg: "请求已取消" });
      this.requestHandlers.delete(latestRequestId);
      
      // 尝试发送取消命令（如果API支持）
      try {
        if (this.socket && this.socket.readyState === WebSocket.OPEN) {
          this.socket.send(JSON.stringify({
            cmd: "cancel_request",
            request_id: latestRequestId
          }));
          this.logger(`已发送取消命令，请求ID: ${latestRequestId}`);
        }
      } catch (error) {
        this.logger(`发送取消命令失败: ${error}`);
      }
      
      // 清除所有其他请求处理程序
      for (const rid of requestIds) {
        if (rid !== latestRequestId) {
          this.requestHandlers.delete(rid);
        }
      }
      
      // 重置状态
      this.isLoading = false;
      this.isWaitingForReply = false;
      
      // 重置任何挂起的消息
      for (const msg of this.messages) {
        if (msg.pending) {
          msg.pending = false;
          if (msg.content === "正在思考中..." || !msg.content) {
            msg.content = "已取消";
          }
          this.updateMessage(msg);
        }
      }
      
      // 通知UI更新
      this.emit(WebSocketEvent.CHAT_UPDATE);
      
      return true;
    }
    
    this.logger(`未找到对应的请求处理程序，取消失败`);
    
    // 无论如何，重置状态
    this.isLoading = false;
    this.isWaitingForReply = false;
    this.emit(WebSocketEvent.CHAT_UPDATE);
    
    return false;
  }
}

// 创建聊天状态管理
export const useChatStore = defineStore('chat', () => {
  // WebSocket服务实例
  const wsService = ref<WebSocketService | null>(null);

  // 聊天状态
  const chatState = reactive({
    messages: [] as ChatMessage[],
    loading: false,
    connectionStatus: 'disconnected' as 'connecting' | 'connected' | 'disconnected' | 'error',
    errorMessage: '',
    availableModels: [] as string[],
    currentModel: '',
    loadingModels: false,
    lastInitializedConfig: '',
    senderKey: Date.now(), // 添加一个键，用于强制更新sender组件
  });

  // 初始化WebSocket服务
  function initWebSocketService(apiUrl: string, apiKey: string) {
    // 记录函数调用到VSCode日志
    const logToVSCode = (message: string) => {
      try {
        if (window.vscodeApi) {
          window.vscodeApi.postMessage({
            type: 'log',
            message: `[WebSocketInit] ${message}`
          });
        }
      } catch (error) {
        console.error('向VSCode发送日志失败', error);
      }
    };
    
    logToVSCode(`初始化WebSocket服务开始 ${apiUrl}`);
    console.log(`[ChatStore] 初始化WebSocket服务开始 ${apiUrl}`);
    
    try {
      if (!apiUrl || !apiKey) {
        const errorMsg = 'API URL或API Key为空，无法初始化WebSocket服务';
        console.error('[ChatStore] ' + errorMsg);
        logToVSCode(errorMsg);
        chatState.errorMessage = 'API配置不完整，请先完成配置';
        chatState.connectionStatus = 'error';
        return;
      }
      
      // 如果已存在WebSocket服务，先断开连接
      if (wsService.value) {
        console.log('[ChatStore] 断开现有WebSocket连接');
        logToVSCode('断开现有WebSocket连接');
        wsService.value.disconnect();
      }

      // 创建新的WebSocket服务实例
      console.log('[ChatStore] 创建新的WebSocket服务实例');
      logToVSCode('创建新的WebSocket服务实例');
      wsService.value = new WebSocketService(apiUrl, apiKey, (message) => {
        // 确保日志同时发送到控制台和VSCode
        console.log(`[WebSocketService] ${message}`);
        
        try {
          if (window.vscodeApi) {
            window.vscodeApi.postMessage({
              type: 'log',
              message: `[WebSocketService] ${message}`
            });
          } else if (vscode) {
            vscode.postMessage({
              type: 'log',
              message: `[WebSocketService] ${message}`
            });
          }
        } catch (err) {
          console.error('向VSCode发送日志失败', err);
        }
      });

      // 设置事件监听
      console.log('[ChatStore] 设置WebSocket事件监听');
      logToVSCode('设置WebSocket事件监听');
      setupWebSocketEvents();
      
      // 连接WebSocket
      console.log('[ChatStore] 开始连接WebSocket');
      logToVSCode('开始连接WebSocket');
      chatState.connectionStatus = 'connecting';
      wsService.value.connect();
      
      // 5秒后检查连接状态
      setTimeout(() => {
        if (!wsService.value) {
          console.error('[ChatStore] WebSocket服务实例为null');
          logToVSCode('WebSocket服务实例为null');
          return;
        }
        
        if (!wsService.value.isConnected) {
          console.error('[ChatStore] WebSocket连接超时');
          logToVSCode('WebSocket连接超时');
          chatState.errorMessage = '连接超时，请检查API配置是否正确';
          chatState.connectionStatus = 'error';
        } else {
          console.log('[ChatStore] WebSocket连接成功');
          logToVSCode('WebSocket连接成功');
        }
      }, 5000);
      
      console.log('[ChatStore] 初始化WebSocket服务完成');
      logToVSCode('初始化WebSocket服务完成');
    } catch (error) {
      console.error('[ChatStore] 初始化WebSocket服务异常:', error);
      logToVSCode(`初始化WebSocket服务异常: ${error instanceof Error ? error.message : String(error)}`);
      chatState.errorMessage = `初始化WebSocket失败: ${error instanceof Error ? error.message : String(error)}`;
      chatState.connectionStatus = 'error';
    }
  }

  // 设置WebSocket事件监听
  function setupWebSocketEvents() {
    if (!wsService.value) {
      console.warn('[ChatStore] WebSocket服务未初始化，无法设置事件监听');
      return;
    }
    
    console.log('[ChatStore] 开始设置WebSocket事件监听...');
    
    wsService.value.on(WebSocketEvent.CONNECTED, () => {
      console.log('[ChatStore] 收到WebSocket CONNECTED事件');
      chatState.connectionStatus = 'connected';
      chatState.errorMessage = '';
    });
    
    wsService.value.on(WebSocketEvent.DISCONNECTED, () => {
      console.log('[ChatStore] 收到WebSocket DISCONNECTED事件');
      chatState.connectionStatus = 'disconnected';
    });
    
    wsService.value.on(WebSocketEvent.ERROR, (error: string) => {
      console.error('[ChatStore] 收到WebSocket ERROR事件:', error);
      chatState.errorMessage = error;
      chatState.connectionStatus = 'error';
      chatState.loading = false;
      chatState.loadingModels = false;
    });
    
    wsService.value.on(WebSocketEvent.MESSAGE, (message: ChatMessage) => {
      console.log('[ChatStore] 收到WebSocket MESSAGE事件', message);
      
      // 检查是否是用户消息，如果是则需要检查是否已存在完全相同的内
      if (message.role === 'user') {
        // 对于用户消息，检查是否已经存在相同内容的用户消息
        const existingSameUser = chatState.messages.find(m => 
          m.role === 'user' && m.content === message.content
        );
        
        if (existingSameUser) {
          console.log('[ChatStore] 跳过添加已存在的用户消息', message.content);
          return; // 直接退出，不处理重复的用户消息
        }
      }
      
      // 检查是否是助手的最终消息（包含stream_finish标记）
      const isAssistantFinalMessage = 
        message.role === 'assistant' && 
        (message.content.includes('"stream_finish":true') || 
         message.content.includes('"stream_finsh":true') ||
         message.content.includes('无响应内容'));
      
      // 跟踪是否需要添加消息
      let shouldAddMessage = true;
      
      // 查找是否已存在具有相同ID前缀的消息
      const existingIndex = chatState.messages.findIndex(m => {
        // 对于助手消息，我们只需要检查id的前缀部分（不包含流序列号）
        if (message.role === 'assistant' && m.role === 'assistant') {
          // 如果是响应消息，可能是response-123的形式
          if (message.id.startsWith('response-') && m.id.startsWith('response-')) {
            // 提取基本ID部分
            const idParts = message.id.split('-');
            const existingIdParts = m.id.split('-');
            
            // 如果基本格式相同(response-数字)，认为是同一消息的更新
            if (idParts.length >= 2 && existingIdParts.length >= 2) {
              return idParts[1] === existingIdParts[1];
            }
          }
        }
        
        // 对于用户消息检查完整ID
        return m.id === message.id;
      });
      
      // 检查消息是否跟上一条消息内容相同
      if (existingIndex === -1 && chatState.messages.length > 0) {
        const lastMessage = chatState.messages[chatState.messages.length - 1];
        
        // 如果消息内容相同且角色相同，这可能是重复触发
        if (lastMessage.role === message.role && lastMessage.content === message.content) {
          console.log('[ChatStore] 跳过添加与上一条消息内容完全相同的消息');
          shouldAddMessage = false;
        }
      }
      
      // 防止添加完全空白的消息
      if (message.content.trim() === '' && message.role === 'assistant') {
        // 仅当不是现有消息的更新时跳过
        if (existingIndex === -1) {
          console.log('[ChatStore] 跳过添加空内容的助手消息');
          shouldAddMessage = false;
        }
      }
      
      if (existingIndex >= 0) {
        // 更新现有消息
        console.log('[ChatStore] 更新现有消息', { 
          id: chatState.messages[existingIndex].id,
          oldLength: chatState.messages[existingIndex].content.length,
          newLength: message.content.length
        });
        
        // 只有当新消息内容更长或是最终消息时才更新
        if (message.content.length > chatState.messages[existingIndex].content.length || isAssistantFinalMessage) {
          chatState.messages[existingIndex] = message;
        }
      } else if (shouldAddMessage) {
        // 添加新消息
        console.log('[ChatStore] 添加新消息', message);
        chatState.messages.push(message);
      }
      
      // 如果是助手的最终消息，重置加载状态
      if (isAssistantFinalMessage) {
        console.log('[ChatStore] 收到助手最终消息，重置加载状态');
        chatState.loading = false;
      }
    });
    
    wsService.value.on(WebSocketEvent.MODEL_LIST, (models: string[]) => {
      console.log('[ChatStore] 收到WebSocket MODEL_LIST事件:', models);
      chatState.loadingModels = false;
      
      if (Array.isArray(models) && models.length > 0) {
        chatState.availableModels = models;
        
        // 如果没有当前模型，设置第一个为当前模型
        if (!chatState.currentModel && models.length > 0) {
          chatState.currentModel = models[0];
        }
      }
    });
    
    wsService.value.on(WebSocketEvent.CHAT_UPDATE, () => {
      console.log('[ChatStore] 收到WebSocket CHAT_UPDATE事件');
      
      // 从WebSocketService中获取最新消息列表
      if (wsService.value && wsService.value.messages.length > 0) {
        chatState.messages = [...wsService.value.messages];
        
        // 检查最新的助手消息是否不再处于pending状态
        const lastAssistantMsg = chatState.messages
          .filter(msg => msg.role === 'assistant')
          .pop();
        
        if (lastAssistantMsg && !lastAssistantMsg.pending) {
          console.log('[ChatStore] 检测到助手消息非pending状态，重置loading状态');
          chatState.loading = false;
        }
      }
    });
    
    console.log('[ChatStore] WebSocket事件监听器设置完成');
  }

  // 发送消息
  async function sendMessage(content: string, model?: string, customAIMessageId?: string): Promise<string> {
    // 记录函数调用到VSCode日志
    const logToVSCode = (message: string) => {
      try {
        if (window.vscodeApi) {
          window.vscodeApi.postMessage({
            type: 'log',
            message: `[ChatStore] ${message}`
          });
        }
      } catch (error) {
        console.error('向VSCode发送日志失败', error);
      }
    };
    
    console.log('[ChatStore] 开始发送消息', { content, connectionStatus: chatState.connectionStatus });
    logToVSCode(`开始发送消息 ${content.substring(0, 30)}... (连接状态 ${chatState.connectionStatus})`);
    
    if (!wsService.value) {
      console.error('[ChatStore] WebSocket服务未初始化，无法发送消息');
      logToVSCode('WebSocket服务未初始化，无法发送消息');
      chatState.errorMessage = 'WebSocket服务未初始化，请刷新页面重试';
      chatState.connectionStatus = 'error';
      throw new Error('WebSocket服务未初始化');
    }
    
    if (!wsService.value.isConnected) {
      console.error('[ChatStore] WebSocket未连接，无法发送消息', wsService.value);
      logToVSCode(`WebSocket未连接，无法发送消息(isConnected: ${wsService.value.isConnected})`);
      chatState.errorMessage = '未连接到AI服务，请先连接';
      chatState.connectionStatus = 'error';
      throw new Error('WebSocket未连接');
    }
    
    if (!content.trim()) {
      console.log('[ChatStore] 消息为空，不发送');
      logToVSCode('消息为空，不发送');
      return '';
    }
    
    // 使用传入的模型或当前模型
    const selectedModel = model || chatState.currentModel;
    
    // 确保有当前模型
    if (!selectedModel && chatState.availableModels.length > 0) {
      console.log('[ChatStore] 自动选择模型', chatState.availableModels[0]);
      logToVSCode(`自动选择模型: ${chatState.availableModels[0]}`);
      chatState.currentModel = chatState.availableModels[0];
    } else if (!selectedModel) {
      console.error('[ChatStore] 没有可用模型');
      logToVSCode('没有可用模型');
      throw new Error('没有可用的AI模型');
    }
    
    console.log(`[ChatStore] 准备发送消息到WebSocket，使用模型 ${selectedModel}`);
    logToVSCode(`准备发送消息到WebSocket，使用模型 ${selectedModel}`);
    chatState.loading = true;
    
    try {
      // 记录开始时间，用于计算响应时间
      const startTime = Date.now();
      
      // 直接发送消息到WebSocket服务
      console.log('[ChatStore] 调用 wsService.sendChatMessage...');
      logToVSCode('调用 wsService.sendChatMessage开始');
      
      if (typeof wsService.value.sendChatMessage !== 'function') {
        console.error('[ChatStore] wsService.sendChatMessage不是一个函数', wsService.value);
        logToVSCode(`wsService.sendChatMessage不是一个函数 ${JSON.stringify(wsService.value)}`);
        throw new Error('WebSocket服务方法不可用');
      }
      
      logToVSCode(`调用sendChatMessage直接...${customAIMessageId ? '使用自定义ID: ' + customAIMessageId : '生成新ID'}`);
      wsService.value.sendChatMessage(content, selectedModel, customAIMessageId);
      logToVSCode('sendChatMessage调用完成，已发送消息');
      
      // 不立即重置loading状态，等待真正的响应通过事件更新
      // 响应处理已经在WebSocketService中注册，会自动更新aiMsg
      
      // 计算响应时间
      const responseTime = Date.now() - startTime;
      console.log(`[ChatStore] 消息已发送，等待服务器响应，发送耗时: ${responseTime}ms`);
      logToVSCode(`消息已发送，等待服务器响应，发送耗时: ${responseTime}ms，内容前50个字符 ${content.substring(0, 50)}`);
      
      return content;
    } catch (error) {
      console.error('[ChatStore] 发送消息失败', error);
      logToVSCode(`发送消息失败 ${error instanceof Error ? error.message : '未知错误'}`);
      chatState.errorMessage = `发送消息失败 ${error instanceof Error ? error.message : '未知错误'}`;
      chatState.connectionStatus = 'error';
      chatState.loading = false;
      throw error;
    }
  }

  // 刷新模型列表
  async function refreshModels() {
    if (!wsService.value || !wsService.value.isConnected) {
      return;
    }
    
    chatState.loadingModels = true;
    
    try {
      const models = await wsService.value.getModelList();
      
      if (Array.isArray(models) && models.length > 0) {
        chatState.availableModels = models;
      }
      
      chatState.loadingModels = false;
    } catch (error) {
      chatState.loadingModels = false;
    }
  }

  // 设置当前模型
  function setCurrentModel(model: string) {
    chatState.currentModel = model;
  }

  // 清空消息列表（上面有一个同名函数需要删除）
  function clearMessages() {
    chatState.messages = [];
  }

  // 手动重连
  function reconnect() {
    if (wsService.value) {
      wsService.value.disconnect();
      chatState.connectionStatus = 'connecting';
      wsService.value.connect();
    }
  }

  // 设置加载状态
  function setLoading(status: boolean) {
    // 如果状态没有变化，直接返回
    if (chatState.loading === status) {
      return;
    }

    console.log(`[ChatStore] 设置loading状态: ${status}`);
    
    try {
      if (window.vscodeApi) {
        window.vscodeApi.postMessage({
          type: 'log',
          message: `[ChatStore] 设置loading状态: ${status}`
        });
      }
    } catch (error) {
      console.error('向VSCode发送日志失败', error);
    }
    
    // 直接设置加载状态
    chatState.loading = status;
    
    // 同步更新WebSocketService的状态
    if (wsService.value) {
      wsService.value.isLoading = status;
      wsService.value.isWaitingForReply = status;
    }
    
    // 如果loading状态被重置为false，检查是否有任何未完成的消息
    // 但避免遍历和修改所有消息，只处理最后一条AI消息
    if (!status) {
      const aiMessages = chatState.messages.filter(m => m.role === 'assistant' && m.pending);
      if (aiMessages.length > 0) {
        // 只处理最后一条pending的AI消息
        const lastPendingMessage = aiMessages[aiMessages.length - 1];
        const index = chatState.messages.indexOf(lastPendingMessage);
        
        if (index !== -1) {
          // 创建消息的副本以确保响应式更新
          const updatedMessage = { ...chatState.messages[index] };
          updatedMessage.pending = false;
          
          // 更新消息
          chatState.messages[index] = updatedMessage;
        }
      }
    }
  }
  
  // 设置连接状态
  function setConnectionStatus(status: 'connecting' | 'connected' | 'disconnected' | 'error') {
    chatState.connectionStatus = status;
  }
  
  // 设置错误消息
  function setErrorMessage(message: string) {
    chatState.errorMessage = message;
  }
  
  // 设置模型列表加载状态
  function setLoadingModels(status: boolean) {
    chatState.loadingModels = status;
  }
  
  // 更新消息列表
  function updateMessages(messages: ChatMessage[]) {
    chatState.messages = messages;
  }
  
  // 添加消息
  function addMessage(message: ChatMessage) {
    chatState.messages.push(message);
  }
  
  // 添加消息到列表
  function addMessageToList(message: ChatMessage) {
    chatState.messages.push(message);
  }
  
  // 更新现有消息
  function updateMessage(index: number, message: ChatMessage) {
    if (index >= 0 && index < chatState.messages.length) {
      chatState.messages[index] = message;
    }
  }

  // 取消当前生成
  function cancelGeneration() {
    console.log('[ChatStore] 尝试取消当前生成');
    
    if (!wsService.value) {
      console.error('[ChatStore] WebSocket服务未初始化，无法取消生成');
      return false;
    }
    
    // 调用WebSocketService的取消方法
    const canceled = wsService.value.cancelCurrentRequest();
    
    // 无论是否成功取消，都重置UI状态
    chatState.loading = false;
    
    // 如果有正在显示的pendingMessage，更新其状态
    const pendingMessage = chatState.messages.find(m => m.pending);
    if (pendingMessage) {
      const index = chatState.messages.indexOf(pendingMessage);
      if (index !== -1) {
        // 更新消息内容
        pendingMessage.content = canceled ? "用户已取消生成" : pendingMessage.content;
        pendingMessage.pending = false;
        chatState.messages[index] = pendingMessage;
      }
    }
    
    return canceled;
  }

  // 获取WebSocketService实例
  function getWebSocketService() {
    return wsService.value;
  }

  // 发送聊天消息 - 简化版本，主要调用 sendMessage 但返回更清晰的结果
  async function sendChatMessage(content: string, model?: string, customAIMessageId?: string): Promise<string> {
    console.log('[ChatStore] sendChatMessage called', { content, model, customAIMessageId });
    return await sendMessage(content, model, customAIMessageId);
  }

  return {
    chatState,
    initWebSocketService,
    sendMessage,
    sendChatMessage,
    refreshModels,
    setCurrentModel,
    clearMessages,
    reconnect,
    // 添加新的actions
    setLoading,
    setConnectionStatus,
    setErrorMessage,
    setLoadingModels,
    updateMessages,
    addMessage,
    addMessageToList,
    updateMessage,
    cancelGeneration,
    getWebSocketService
  };
});
