import { defineStore } from 'pinia';
import { ref, computed } from 'vue';
import { theme as antdTheme } from 'ant-design-vue';

// 定义主题颜色接口
export interface ThemeColors {
  // 主题类型
  themeType?: 'light' | 'dark';
  
  // 基本颜色
  foreground?: string;
  background?: string;
  disabledForeground?: string;
  
  // 输入框
  inputBackground?: string;
  inputForeground?: string;
  inputPlaceholderForeground?: string;
  inputBorder?: string;
  
  // 按钮
  buttonBackground?: string;
  buttonForeground?: string;
  buttonHoverBackground?: string;
  buttonSecondaryBackground?: string;
  buttonSecondaryForeground?: string;
  buttonSecondaryHoverBackground?: string;
  
  // 标签页
  tabActiveForeground?: string;
  tabInactiveForeground?: string;
  tabHoverForeground?: string;
  tabActiveBorder?: string;
  tabActiveBackground?: string;
  tabInactiveBackground?: string;
  tabHoverBackground?: string;
  
  // 边框和分隔线
  panelBorder?: string;
  widgetBorder?: string;
  
  // 链接
  textLinkForeground?: string;
  textLinkActiveForeground?: string;
  
  // 滚动条
  scrollbarSliderBackground?: string;
  scrollbarSliderHoverBackground?: string;
  scrollbarSliderActiveBackground?: string;
  
  // 聊天相关
  chatRequestBackground?: string;
  chatRequestBorder?: string;
  chatRequestForeground?: string;
  chatResponseBackground?: string;
  chatResponseBorder?: string;
  chatResponseForeground?: string;
  
  // 代码块和预格式化文本
  textCodeBlockBackground?: string;
  textPreformatForeground?: string;
  textPreformatBackground?: string;
  textBlockQuoteBackground?: string;
  textBlockQuoteBorder?: string;
  
  // 菜单
  menuBackground?: string;
  menuForeground?: string;
  menuSelectionBackground?: string;
  menuSelectionForeground?: string;
  menuBorder?: string;
  menuSeparatorBackground?: string;
  
  // 列表
  listActiveSelectionBackground?: string;
  listActiveSelectionForeground?: string;
  listHoverBackground?: string;
  listHoverForeground?: string;
  
  // 其他UI元素
  descriptionForeground?: string;
  editorWidgetBackground?: string;
  editorWidgetForeground?: string;
  focusBorder?: string;
  progressBarBackground?: string;
  
  // 边框
  contrastBorder?: string;
  contrastActiveBorder?: string;
}

// 默认颜色，用于fallback
const defaultThemeColors: ThemeColors = {
  themeType: 'dark',
  
  foreground: '#CCCCCC',
  background: '#1E1E1E',
  disabledForeground: '#888888',
  
  inputBackground: '#3C3C3C',
  inputForeground: '#CCCCCC',
  inputPlaceholderForeground: '#888888',
  inputBorder: '#3C3C3C',
  
  buttonBackground: '#0E639C',
  buttonForeground: '#FFFFFF',
  buttonHoverBackground: '#1177BB',
  buttonSecondaryBackground: '#3A3D41',
  buttonSecondaryForeground: '#FFFFFF',
  buttonSecondaryHoverBackground: '#45494E',
  
  tabActiveForeground: '#FFFFFF',
  tabInactiveForeground: '#AAAAAA',
  tabHoverForeground: '#FFFFFF',
  tabActiveBorder: '#0E639C',
  tabActiveBackground: '#1E1E1E',
  tabInactiveBackground: '#2D2D2D',
  tabHoverBackground: '#2A2D2E',
  
  panelBorder: '#808080',
  widgetBorder: '#3C3C3C',
  
  textLinkForeground: '#3794FF',
  textLinkActiveForeground: '#3794FF',
  
  scrollbarSliderBackground: 'rgba(121, 121, 121, 0.4)',
  scrollbarSliderHoverBackground: 'rgba(100, 100, 100, 0.7)',
  scrollbarSliderActiveBackground: 'rgba(191, 191, 191, 0.4)',
  
  chatRequestBackground: 'rgba(56, 56, 56, 0.6)',
  chatRequestBorder: 'rgba(86, 86, 86, 0.6)',
  chatRequestForeground: '#CCCCCC',
  chatResponseBackground: 'rgba(38, 79, 120, 0.6)',
  chatResponseBorder: 'rgba(58, 109, 150, 0.6)',
  chatResponseForeground: '#FFFFFF',
  
  textCodeBlockBackground: '#1E1E1E',
  textPreformatForeground: '#D4D4D4',
  textPreformatBackground: '#0D0D0D',
  textBlockQuoteBackground: 'rgba(68, 68, 68, 0.2)',
  textBlockQuoteBorder: '#608B4E',
  
  menuBackground: '#252526',
  menuForeground: '#CCCCCC',
  menuSelectionBackground: '#04395E',
  menuSelectionForeground: '#FFFFFF',
  menuBorder: '#454545',
  menuSeparatorBackground: '#454545',
  
  listActiveSelectionBackground: '#094771',
  listActiveSelectionForeground: '#FFFFFF',
  listHoverBackground: 'rgba(90, 93, 94, 0.31)',
  listHoverForeground: '#FFFFFF',
  
  descriptionForeground: '#AAAAAA',
  editorWidgetBackground: '#252526',
  editorWidgetForeground: '#CCCCCC',
  focusBorder: '#007FD4',
  progressBarBackground: '#0E70C0',
  
  contrastBorder: '#6F6F6F',
  contrastActiveBorder: '#F38518',
};

// Ant Design暗色主题算法配置
const darkAlgorithm = antdTheme.darkAlgorithm;
// Ant Design亮色主题算法配置
const defaultAlgorithm = antdTheme.defaultAlgorithm;

export const useThemeStore = defineStore('theme', () => {
  // 主题颜色状态
  const themeColors = ref<ThemeColors>({ ...defaultThemeColors });
  
  // 主题类型
  const themeType = computed(() => themeColors.value.themeType || 'dark');
  const isDarkTheme = computed(() => themeType.value === 'dark');
  
  // 获取Ant Design主题配置
  const antdThemeConfig = computed(() => {
    return {
      algorithm: isDarkTheme.value ? darkAlgorithm : defaultAlgorithm,
      token: {
        colorPrimary: themeColors.value.buttonBackground || '#0E639C',
        colorLink: themeColors.value.buttonBackground || '#0E639C',
        borderRadius: 4,
      },
      components: {
        Button: {
          colorPrimary: themeColors.value.buttonBackground,
          colorPrimaryHover: themeColors.value.buttonHoverBackground,
          colorPrimaryActive: themeColors.value.buttonHoverBackground,
          colorPrimaryText: themeColors.value.buttonForeground,
        },
        Input: {
          colorBgContainer: themeColors.value.inputBackground,
          colorText: themeColors.value.inputForeground,
          colorTextPlaceholder: themeColors.value.inputPlaceholderForeground,
          colorBorder: themeColors.value.inputBorder,
        }
      }
    };
  });
  
  // 获取带有默认值的颜色
  const getColor = (colorId: keyof ThemeColors) => {
    return themeColors.value[colorId] || defaultThemeColors[colorId] || '';
  };
  
  // 设置主题颜色
  const setThemeColors = (colors: ThemeColors) => {
    // 合并新颜色，保留默认值作为回退
    themeColors.value = { ...defaultThemeColors, ...colors };
    // 动态设置 CSS 变量
    applyThemeColorsToCSS();
  };
  
  // 将主题颜色应用为 CSS 变量
  const applyThemeColorsToCSS = () => {
    const root = document.documentElement;
    
    // 首先设置主题类型
    if (isDarkTheme.value) {
      root.classList.add('vscode-dark');
      root.classList.remove('vscode-light');
    } else {
      root.classList.add('vscode-light');
      root.classList.remove('vscode-dark');
    }
    
    // 遍历所有颜色并设置为 CSS 变量
    for (const [key, value] of Object.entries(themeColors.value)) {
      if (value && key !== 'themeType') {
        // 转换 camelCase 为 kebab-case：例如 buttonBackground 变为 --vscode-button-background
        const cssVarName = '--vscode-' + key.replace(/([A-Z])/g, '-$1').toLowerCase();
        root.style.setProperty(cssVarName, value);
      }
    }
  };
  
  // 请求主题颜色
  const requestThemeColors = () => {
    // 判断是否在 VS Code webview 环境中
    if (typeof acquireVsCodeApi !== 'undefined') {
      try {
        const vscode = acquireVsCodeApi();
        vscode.postMessage({ type: 'getThemeColors' });
      } catch (error) {
        console.error('Failed to request theme colors from VS Code:', error);
      }
    }
  };
  
  // 初始化
  const initialize = () => {
    requestThemeColors();
    // 在页面加载后应用默认主题颜色
    applyThemeColorsToCSS();
  };
  
  return {
    themeColors,
    themeType,
    isDarkTheme,
    antdThemeConfig,
    getColor,
    setThemeColors,
    applyThemeColorsToCSS,
    requestThemeColors,
    initialize
  };
}); 